#ifndef TILDA_WINDOW_H
#define TILDA_WINDOW_H

/*
Object Creation Order
========================================
tilda_window_class_init()
tilda_window_constructor() BEGINS
	tilda_window_instance_init()
	tilda_window_set_property() FOR EACH CTOR PROPERTY USED
tilda_window_constructor() COMPLETES

... usage ...

g_object_unref(...)
tilda_window_dispose()
tilda_window_finalize()
*/

#include <glib.h>
#include <gtk/gtk.h>

#include "tilda-terminal.h"

#define TILDA_TYPE_WINDOW				(tilda_window_get_type())
#define TILDA_WINDOW(obj)				(G_TYPE_CHECK_INSTANCE_CAST ((obj), TILDA_TYPE_WINDOW, TildaWindow))
#define TILDA_WINDOW_CLASS(klass)		(G_TYPE_CHECK_CLASS_CAST ((klass), TILDA_TYPE_WINDOW, TildaWindowClass))
#define TILDA_IS_WINDOW(obj)			(G_TYPE_CHECK_INSTANCE_TYPE ((obj), TILDA_TYPE_WINDOW))
#define TILDA_IS_WINDOW_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), TILDA_TYPE_WINDOW))
#define TILDA_WINDOW_GET_CLASS(obj)		(G_TYPE_INSTANCE_GET_CLASS ((obj), TILDA_TYPE_WINDOW, TildaWindowClass))

typedef struct _TildaWindow TildaWindow;
typedef struct _TildaWindowClass TildaWindowClass;

struct _TildaWindow {
	GObject parent;
	gboolean dispose_has_run;

	/* Instance Members */
	GtkWidget *window;
	GtkWidget *notebook;
	GPtrArray *terms;

	/* Accelerator-related instance members */
	GtkAccelGroup *accel_group;
	gchar *accel_quit;
	gchar *accel_next_tab;
	gchar *accel_prev_tab;
	gchar *accel_add_term;
	gchar *accel_remove_term;
	gchar *accel_copy;
	gchar *accel_paste;
	gchar *accel_goto_1;
	gchar *accel_goto_2;
	gchar *accel_goto_3;
	gchar *accel_goto_4;
	gchar *accel_goto_5;
	gchar *accel_goto_6;
	gchar *accel_goto_7;
	gchar *accel_goto_8;
	gchar *accel_goto_9;
	gchar *accel_goto_10;

	gint number;
	GObject *controller; /* pointer back to TildaController */
	enum window_states { WINDOW_UP, WINDOW_DOWN } state;

	gchar *key;

	gint height;
	gint width;
	gint x_position;
	gint y_position;
	gint animation_delay;
	gint initial_terminals;

	GtkPositionType tab_position;
	GtkPositionType animation_orientation;

	gboolean keep_above;
	gboolean skip_taskbar_hint;
	gboolean stick;
	gboolean hidden_at_start;
	gboolean centered_horizontally;
	gboolean centered_vertically;
	gboolean full_width_tabs;
	gboolean always_show_tabs;
	gboolean always_show_border;
	gboolean have_real_transparency;
};

struct _TildaWindowClass {
	GObjectClass parent;

	/* class members */
};

/* used by TILDA_TYPE_WINDOW */
GType tilda_window_get_type (void);

/* API */
gboolean tilda_window_close (TildaWindow *self);
gboolean tilda_window_add_terminal (TildaWindow *self);
gboolean tilda_window_remove_terminal (TildaWindow *self, gint terminal_number);

#endif /* TILDA_WINDOW_H */

/* vim: set ts=4 sts=4 sw=4 noet tw=112: */
